@@ -226,7 +226,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     """
     def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss',
                 metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False, save_func=None,
-                 keep_only_recent=False, save_every=True):
+                 keep_only_recent=False, save_every=True, batch_save=False, batch_save_step=100):
         """
 
         Args:
@@ -253,6 +253,8 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         self.save_func = save_func
         self.keep_only_recent = keep_only_recent
         self.save_every = save_every
+        self.batch_save = batch_save
+        self.batch_save_step = batch_save_step
 
     def save_model(self, file_name):
         if self.enable:
@@ -261,6 +263,12 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
             else:
                 self.model.save(file_name, include_optimizer=self.include_optimizer)
 
+    def on_train_batch_end(self, batch, logs=None):
+        if self.batch_save and batch % self.batch_save_step == 0:
+            print("\nSave model in batch ...")
+            file_name = f'{self.save_root}/{self.file_name}_{self.epoch:04d}_batch.h5'
+            self.save_model(file_name)
+
     def on_epoch_end(self, epoch, logs=None):
         try:
             epoch += self.epoch
@@ -434,7 +442,7 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
                      confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, test_dataset=None, figure_size=(12, 10), model_out_idx=-1,
-                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0,
+                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, batch_save=False,
                      save_metric='val_loss', save_file_name="my_model", metric_type="loss", save_func=None,
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True,
                      sparsity_callback=False, sparsity_threshold=0.05):
@@ -511,7 +519,7 @@ def get_tf_callbacks(root,
             save_root = log_root_
         callbacks_.append(
             ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric,
-                               file_name=save_file_name, metric_type=metric_type, save_func=save_func)
+                               file_name=save_file_name, metric_type=metric_type, save_func=save_func, batch_save=batch_save)
         )
 
     if earlystop_callback:
